@@ -1337,9 +1337,9 @@ class HL7CdaBuilder:
 		
 		# CDA file logging
 		if config.LOG_CDA_TOFILE:
-			if not os.path.exists('log') : os.makedirs('log')
-			if not os.path.exists('log/cda') : os.makedirs('log/cda')
-			file_log = "log/cda/CDA_{}.xml".format(content_id)
+			if not os.path.exists(config.LOG_DIR_PATH + '/cda') :
+				os.makedirs(config.LOG_DIR_PATH + '/cda')
+			file_log = config.LOG_DIR_PATH + "/cda/CDA_{}.xml".format(content_id)
 			logger.info("Writing CDA document to log file %s", file_log)
 			text_file = open(file_log, "wb")
 			text_file.write(etree.tostring(CD, pretty_print = True, xml_declaration = False, encoding = 'utf-8'))
